@@ -43,6 +43,17 @@ def get_spark(scale=0, queue=None):
         else:
             queue = "airflow_job"
     os.environ["ARROW_PRE_0_15_IPC_FORMAT"] = "1"
+
+    import os
+    import tempfile
+    from skt.vault_utils import get_secrets
+
+    key = get_secrets("gcp/sktaic-datahub/dataflow")["config"]
+    key_file_name = tempfile.mkstemp()[1]
+    with open(key_file_name, "wb") as key_file:
+        key_file.write(key.encode())
+        os.environ["GOOGLE_APPLICATION_CREDENTIALS"] = key_file.name
+
     if scale in [1, 2, 3, 4]:
         spark = (
             SparkSession.builder.config("spark.app.name", app_name)
@@ -56,6 +67,7 @@ def get_spark(scale=0, queue=None):
             .config("spark.port.maxRetries", "128")
             .config("spark.executorEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
             .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
+            .config("spark.jars", "gs://external_libs/spark/jars/spark-bigquery-with-dependencies_2.11-0.16.1.jar",)
             .enableHiveSupport()
             .getOrCreate()
         )
@@ -74,6 +86,7 @@ def get_spark(scale=0, queue=None):
             .config("spark.port.maxRetries", "128")
             .config("spark.executorEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
             .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
+            .config("spark.jars", "gs://external_libs/spark/jars/spark-bigquery-with-dependencies_2.11-0.16.1.jar",)
             .enableHiveSupport()
             .getOrCreate()
         )
@@ -99,7 +112,16 @@ def hive_get_result(query):
     return result
 
 
-def hive_to_pandas(query):
+def hive_to_pandas(query, scale=0):
+    if scale == 1:
+        import pandas
+
+        conn = get_hive_conn()
+        df = pandas.read_sql(query, conn)
+        df.info()
+        conn.close()
+        return df
+
     import uuid
 
     tmp_id = str(uuid.uuid4()).replace("-", "_")
@@ -108,10 +130,14 @@ def hive_to_pandas(query):
     c = conn.cursor()
     c.execute("set parquet.column.index.access=false")
     c.execute(ctas)
+    hdfs = get_hdfs_conn()
+    table_path = hdfs.ls(f"/warehouse/tablespace/managed/hive/dumbo.db/{tmp_id}")[0]
+    hdfs.close()
+    df = parquet_to_pandas(table_path)
+    c.execute(f"DROP TABLE dumbo.{tmp_id}")
     c.close()
     conn.close()
-    table_path = f"/warehouse/tablespace/managed/hive/dumbo.db/{tmp_id}/delta_0000001_0000001_0000"
-    return parquet_to_pandas(table_path)
+    return df
 
 
 def parquet_to_pandas(hdfs_path):
